@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,39 +32,39 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_CHOKE_COMMAND_H_
-#define _D_PEER_CHOKE_COMMAND_H_
+#ifndef D_PEER_CHOKE_COMMAND_H
+#define D_PEER_CHOKE_COMMAND_H
 
 #include "Command.h"
-#include "BtContextAwareCommand.h"
-#include "DownloadEngine.h"
-#include "TimeA2.h"
-#include "RequestGroupAware.h"
 
-class PeerChokeCommand : public Command,
-			 public BtContextAwareCommand,
-			 public RequestGroupAware
-{
+#include <memory>
+
+namespace aria2 {
+
+class DownloadEngine;
+class BtRuntime;
+class PeerStorage;
+
+class PeerChokeCommand : public Command {
 private:
-  int32_t interval;
-  DownloadEngine* e;
-  int32_t rotate;
-  Time checkPoint;
+  DownloadEngine* e_;
 
-  void orderByUploadRate(Peers& peers) const;
-  void orderByDownloadRate(Peers& peers) const;
-  void optUnchokingPeer(Peers& peers) const;
+  std::shared_ptr<PeerStorage> peerStorage_;
 
+  std::shared_ptr<BtRuntime> btRuntime_;
 public:
-  PeerChokeCommand(int32_t cuid,
-		   RequestGroup* requestGroup,
-		   DownloadEngine* e,
-		   const BtContextHandle& btContext,
-		   int32_t interval);
+  PeerChokeCommand(cuid_t cuid,
+                   DownloadEngine* e);
 
   virtual ~PeerChokeCommand();
 
-  virtual bool execute();
+  virtual bool execute() CXX11_OVERRIDE;
+
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
+
+  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);
 };
 
-#endif // _D_PEER_CHOKE_COMMAND_H_
+} // namespace aria2
+
+#endif // D_PEER_CHOKE_COMMAND_H
